@@ -18,7 +18,7 @@
 #
 # This translation was updated for Oddmuse 1.354.
 #
-$ModulesDescription .= '<p>$Id: bulgarian-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: bulgarian-utf8.pl,v 1.3 2005/07/02 00:02:02 as Exp $</p>';
 %Translate = split('\n',<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Не е разрешено четенето: блокиран потребител, IP адрес или мрежа.
@@ -50,6 +50,8 @@ image
 
 download
 
+CGI Internal error: %s
+
 Invalid action parameter %s
 Невалидна команда: %s
 Invalid URL.
@@ -206,8 +208,6 @@ View current revision
 Виж актуалната версия
 View all changes
 Виж всички промени
-new comment
-Нов коментар
 Homepage URL:
 
 s
@@ -264,6 +264,8 @@ Cannot open %s
 не може да се отвори: %s
 Cannot write %s
 Не може да се запише: %s
+Cannot create %s
+
 Could not get %s lock
 Не може да се резервират изключителни права върху %s.
 This operation may take several seconds...
@@ -494,6 +496,8 @@ The page %s does not exist
 
 The page %s already exists
 
+Cannot rename %1 to %2
+
 Renamed to %s
 
 Renamed from %s
@@ -518,6 +522,10 @@ Next
 
 Calendar %s
 
+Clustermap
+
+Pages without a Cluster
+
 Comments on 
 
 Comment on 
@@ -556,7 +564,43 @@ Template without parameters
 
 The template %s is either empty or does not exist.
 
-%s returned no data.
+Register for %s
+
+Please choose a username of the form "FirstLast" using your real name.
+
+The passwords do not match.
+
+The password must be at least %s characters.
+
+That email address is invalid.
+
+The username %s has already been registered.
+
+Your registration for %s has been submitted.
+
+  Please allow time for the webmaster to approve your request.
+
+An account was created for %s.
+
+Login to %s
+
+Username and/or password are incorrect.
+
+Logged in as %s.
+
+Logout of %s
+
+Logout of %s?
+
+Logged out of %s
+
+You are now logged out.
+
+Register a new account
+
+Login
+
+Logout
 
 Clearing Cache
 
@@ -566,6 +610,16 @@ Generating Link Database
 
 The 404 handler extension requires the link data extension (links.pl).
 
+LocalMap
+
+No page id for action localmap
+
+Requested page %s does not exist
+
+Local Map for %s
+
+view
+
 Orphan List
 
 Trail: 
@@ -584,14 +638,30 @@ All Referrers
 Всички линкове
 Referrers
 Линкове
-Updating %s
+Rebuild index for searching
+
+Rebuilding Index
+
+Search::FreeText is not available on this system.
+
+Rebuilding index not done.
+
+(Rebuilding the index can only be done once every 12 hours.)
 
 Search term missing.
 
+Result pages: 
+
+(%s results)
+
+Slideshow:%s
+
 Static Copy
 
 Back to %s
 Обратно към %s
+Tag
+
 Alternatively, use one of the following templates:
 
 Thread: %s
