@@ -1,4 +1,4 @@
-# Copyright (C) 2004  Alex Schroeder <alex@emacswiki.org>
+# Copyright (C) 2004, 2005  Alex Schroeder <alex@emacswiki.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,15 +16,16 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: calendar.pl,v 1.29 2004/10/12 22:09:12 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: calendar.pl,v 1.36 2005/01/06 12:05:15 as Exp $</p>';
 
 use vars qw($CalendarOnEveryPage $CalendarUseCal);
 
-$DefaultStyleSheet .= <<'EOT' unless $DefaultStyleSheet =~ /div\.month/; # mod_perl?
-div.month { float:right; margin:0; padding-left:1ex; padding-right:1ex; }
+$DefaultStyleSheet .= q{
+div.month { margin:0; padding:0; font-size:x-small; float:right; }
+div.content div.month { float:none; }
 div.footer { clear:both; }
-div.year div.month { float:left; }
-div.month pre { margin:0; padding:0; background-color:#ffe; }
+div.year div.month { float:left; font-size:medium; padding:1ex; }
+div.month pre { margin:0; padding:0 0 0 1ex; background-color:#ffe; width:21ex; }
 div.month a { text-decoration:none; color:inherit; }
 div.month span.title a { background-color:inherit; }
 div.month a.exact { background-color:#eef; }
@@ -37,7 +38,7 @@ div.month a[class~="today"][class~="collection"] { background-color:#faf; }
   div.year div.month { display: block; }
   div.year div.month a { display: inline; }
 }
-EOT
+} unless $DefaultStyleSheet =~ /div\.month/; # mod_perl?
 
 $CalendarOnEveryPage = 1;
 $CalendarUseCal = 1;
@@ -121,9 +122,9 @@ sub DoCollect {
     $CollectingJournal = 1;
     # Now save information required for saving the cache of the current page.
     local (%Page, $OpenPageName);
-    print '<div class="journal collection">';
+    print $q->start_div({-class=>'content journal collection'});
     PrintAllPages(1, 1, @matches);
-    print '</div>';
+    print $q->end_div();
   }
   $CollectingJournal = 0;
   PrintFooter();
@@ -134,16 +135,18 @@ push(@MyRules, \&CalendarRule);
 sub CalendarRule {
   if (/\G(calendar:(\d\d\d\d))/gc) {
     my $oldpos = pos;
+    Clean(CloseHtmlEnvironments() . $q->start_div({-class=>'cal year'}));
     Dirty($1);
     PrintYearCalendar($2);
+    print $q->end_div();
     pos = $oldpos;
-    return '';
+    return AddHtmlEnvironment('p');
   } elsif (/\G(month:(\d\d\d\d)-(\d\d))/gc) {
     my $oldpos = pos;
     Dirty($1);
-    print Cal($2, $3);
+    print CloseHtmlEnvironments() . Cal($2, $3);
     pos = $oldpos;
-    return '';
+    return AddHtmlEnvironment('p');
   } elsif (/\G(month:([+-]\d\d?))/gc) {
     my $oldpos = pos;
     Dirty($1);
@@ -153,9 +156,9 @@ sub CalendarRule {
     $mon += 1 + $delta;
     while ($mon < 1) { $year -= 1; $mon += 12; };
     while ($mon > 12) { $year += 1; $mon -= 12; };
-    print Cal($year, $mon);
+    print CloseHtmlEnvironments() . Cal($year, $mon);
     pos = $oldpos;
-    return '';
+    return AddHtmlEnvironment('p');
   }
   return undef;
 }
@@ -163,15 +166,13 @@ sub CalendarRule {
 sub PrintYearCalendar {
   my $year = shift;
   my @pages = AllPagesList();
-  print '<div class="cal year">';
   print $q->p({-class=>nav},
 	      ScriptLink('action=calendar;year=' . ($year-1), T('Previous')),
-	      ' | ',
+	      '|',
 	      ScriptLink('action=calendar;year=' . ($year+1), T('Next')));
   for $mon ((1..12)) {
     print Cal($year, $mon, 1);
   }
-  print '</div>';
 }
 
 $Action{calendar} = \&DoYearCalendar;
@@ -181,6 +182,8 @@ sub DoYearCalendar {
   $year += 1900;
   $year = GetParam('year', $year);
   print GetHeader('', Ts('Calendar %s', $year), '');
+  print $q->start_div({-class=>'content cal year'});
   PrintYearCalendar($year);
+  print $q->end_div();
   PrintFooter();
 }
