@@ -1,4 +1,4 @@
-# Copyright (C) 2004  Alex Schroeder <alex@emacswiki.org>
+# Copyright (C) 2004, 2005  Alex Schroeder <alex@emacswiki.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: markup.pl,v 1.13 2004/09/27 21:38:52 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: markup.pl,v 1.17 2005/01/06 11:35:04 as Exp $</p>';
 
 use vars qw(%MarkupPairs %MarkupSingles %MarkupLines);
 
@@ -51,11 +51,10 @@ my $markup_pairs_re = '';
 my $markup_singles_re = '';
 my $markup_lines_re = '';
 
-*OldMarkupInitVariables = *InitVariables;
-*InitVariables = *NewMarkupInitVariables;
+# do this later so that the user can customize the vars
+push(@MyInitVariables, \&MarkupInit);
 
-sub NewMarkupInitVariables {
-  OldMarkupInitVariables();
+sub MarkupInit {
   $markup_pairs_re = '\G([' . join('', (map { quotemeta(QuoteHtml($_)) }
 					keys(%MarkupPairs))) . '])';
   $markup_pairs_re = qr/\G${markup_pairs_re}${words}\1${noword}/;
@@ -85,7 +84,7 @@ sub MarkupTag {
 }
 
 sub MarkupRule {
-  if ($bol and m/$markup_lines_re/gc) {
+  if ($bol and %MarkupLines and m/$markup_lines_re/gc) {
     my ($tag, $str) = ($1, $2);
     $str = $q->span($tag) . $str;
     while (m/$markup_lines_re/gc) {
@@ -93,9 +92,9 @@ sub MarkupRule {
     }
     return MarkupTag($MarkupLines{UnquoteHtml($tag)}, $str);
   }
-  elsif (m/$markup_pairs_re/gc) {
+  elsif (%MarkupPairs and m/$markup_pairs_re/gc) {
     return MarkupTag($MarkupPairs{UnquoteHtml($1)}, $2);
-  } elsif (m/$markup_singles_re/gc) {
+  } elsif (%MarkupSingles and m/$markup_singles_re/gc) {
     return $MarkupSingles{UnquoteHtml($1)};
   } elsif ($MarkupPairs{'/'} and m|\G~/|gc) {
     return '~/'; # fix ~/elisp/ example
