@@ -17,7 +17,7 @@
 #
 # This translation was last checked for Oddmuse version 1.195.
 #
-$ModulesDescription .= '<p>$Id: portuguese-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: portuguese-utf8.pl,v 1.3 2005/07/02 00:03:28 as Exp $</p>';
 %Translate = split('\n',<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Leitura não permitida: usuário, ip, ou rede está bloqueada.
@@ -49,6 +49,8 @@ image
 
 download
 
+CGI Internal error: %s
+
 Invalid action parameter %s
 Parametro de ação inválido %s
 Invalid URL.
@@ -205,8 +207,6 @@ View current revision
 Veja a versão corrente
 View all changes
 Veja todas os câmbios
-new comment
-Comentário novo
 Homepage URL:
 
 s
@@ -263,6 +263,8 @@ Cannot open %s
 Não foi possível abrir %s
 Cannot write %s
 Não foi possível escrever %s
+Cannot create %s
+
 Could not get %s lock
 Não foi possível conseguir a trava %s
 This operation may take several seconds...
@@ -493,6 +495,8 @@ The page %s does not exist
 A página %s não existe
 The page %s already exists
 A página %s já existe
+Cannot rename %1 to %2
+
 Renamed to %s
 
 Renamed from %s
@@ -517,6 +521,10 @@ Next
 Próximo
 Calendar %s
 Calendário para %s
+Clustermap
+
+Pages without a Cluster
+
 Comments on 
 
 Comment on 
@@ -555,7 +563,43 @@ Template without parameters
 
 The template %s is either empty or does not exist.
 
-%s returned no data.
+Register for %s
+
+Please choose a username of the form "FirstLast" using your real name.
+
+The passwords do not match.
+
+The password must be at least %s characters.
+
+That email address is invalid.
+
+The username %s has already been registered.
+
+Your registration for %s has been submitted.
+
+  Please allow time for the webmaster to approve your request.
+
+An account was created for %s.
+
+Login to %s
+
+Username and/or password are incorrect.
+
+Logged in as %s.
+
+Logout of %s
+
+Logout of %s?
+
+Logged out of %s
+
+You are now logged out.
+
+Register a new account
+
+Login
+
+Logout
 
 Clearing Cache
 
@@ -565,6 +609,16 @@ Generating Link Database
 
 The 404 handler extension requires the link data extension (links.pl).
 
+LocalMap
+
+No page id for action localmap
+
+Requested page %s does not exist
+
+Local Map for %s
+
+view
+
 Orphan List
 
 Trail: 
@@ -583,14 +637,30 @@ All Referrers
 
 Referrers
 
-Updating %s
+Rebuild index for searching
+
+Rebuilding Index
+
+Search::FreeText is not available on this system.
+
+Rebuilding index not done.
+
+(Rebuilding the index can only be done once every 12 hours.)
 
 Search term missing.
 
+Result pages: 
+
+(%s results)
+
+Slideshow:%s
+
 Static Copy
 
 Back to %s
 Voltar para %s
+Tag
+
 Alternatively, use one of the following templates:
 
 Thread: %s
