@@ -21,10 +21,7 @@
 # Create a modules subdirectory in your data directory, and put the
 # file in there. It will be loaded automatically.
 #
-# This translation was last checked for OddMuse version 1.517.
-# Checked and updated by Johan Adler 050106
-#
-$ModulesDescription .= '<p>$Id: swedish-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: swedish-utf8.pl,v 1.10 2005/07/02 00:03:28 as Exp $</p>';
 %Translate = split('\n',<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Läsning inte tillåten: användare, ip eller nätverk är blockerat.
@@ -45,7 +42,7 @@ historik
 %s returned no data, or LWP::UserAgent is not available.
 Antingen returnerade %s inget data, eller så finns inte LWP::UserAgent tillgängligt.
 RSS parsing failed for %s
-Misslyckades med RSS parsningen av %s
+Misslyckades med RSS-tolkningen av %s
 No items found in %s.
 Ingen information funnen i %s.
  . . . . 
@@ -56,6 +53,8 @@ image
 bild
 download
 ladda ned
+CGI Internal error: %s
+
 Invalid action parameter %s
 Ogiltig parameter %s
 Invalid URL.
@@ -137,7 +136,7 @@ av
 Rolling back changes
 Återställer
 Missing target for rollback.
-Mål för återställning saknas
+Mål för återställning saknas.
 Target for rollback is too far back.
 Mål för återställning för gammalt.
 Rollback to %s
@@ -145,11 +144,11 @@ Rollback to %s
 %s rolled back
 %s återställd
 Index of all pages
-Index över alla sidor
+Innehållsförteckning
 Wiki Version
-
+Wikiversion
 Unlock Wiki
-
+Lås upp wiki
 Recent Visitors
 Senaste besökare
 Password
@@ -161,17 +160,17 @@ Lås upp wikin
 Lock site
 Lås wikin
 Unlock %s
-
+Lås upp %s
 Lock %s
-
+Lås %s
 Administration
 
 Actions:
-
+Verktyg:
 Important pages:
-
+Viktiga sidor:
 To mark a page for deletion, put <strong>%s</strong> on the first line.
-
+För att markera en sida för radering, skriv <strong>%s</strong> på första raden.
 [Home]
 [Startsida]
 redirected from %s
@@ -189,7 +188,7 @@ Databas sparad i tillfällig katalog %s
 The same page on other sites:
 Samma sida på andra siter:
 EditNearLinks
-
+Redigera närlänkar
 Last edited
 Senast ändrad
 Edited
@@ -212,10 +211,8 @@ View current revision
 Visa rådande version
 View all changes
 Visa alla ändringar
-new comment
-ny kommentar
 Homepage URL:
-Startsidans URL:
+URL till hemsida:
 s
 s
 Save
@@ -225,7 +222,7 @@ Förhandsgranska
 Search:
 Sök:
 f
-
+k
 Replace:
 Ersätt:
 Validate HTML
@@ -270,6 +267,8 @@ Cannot open %s
 Kan inte öppna %s
 Cannot write %s
 Kan inte skriva %s
+Cannot create %s
+Kan inte skapa %s
 Could not get %s lock
 Kunde inte låsa %s
 This operation may take several seconds...
@@ -323,7 +322,7 @@ Skriv text istället för den här filen.
 Replace this text with a file.
 Använd en fil i stället för den här texten.
 File to upload: 
-
+Fil att ladda upp: 
 Files of type %s are not allowed.
 Filer av typen %s är inte tillåtna.
 Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
@@ -347,17 +346,17 @@ Den här funktionen kan bara utföras av adminstratörer...
 Rule "%1" matched "%2" on this page.
 Regel "%1"  matchade "%2" på denna sida.
 Without normal pages
-
+Utan vanliga sidor
 Include normal pages
-
+Med vanliga sidor
 Without permanent anchors
-
+Utan permanenta ankare
 Include permanent anchors
-
+Med permanenta ankare
 Without near pages
-
+Utan nära sidor
 Include near pages
-
+Med nära sidor
 (for %s)
 (för: %s)
 %s pages found.
@@ -397,7 +396,7 @@ Odefinierad_exempelsida
 [[%s]] cannot be defined.
 [[%s]] kan inte definieras.
 Only an administrator can create %s.
-Bara en administratör kan skapa %s.
+Endast en administratör kan skapa %s.
 Transfer Error: %s
 Överföringsfel: %s
 Browser reports no file info.
@@ -419,7 +418,7 @@ Anonym
 Cannot delete the index file %s.
 Kan inte radera index-filen %s.
 Please check the directory permissions.
-Vänligen kontrollera biblioteksrättigheter
+Vänligen kontrollera biblioteksrättigheter.
 Your changes were not saved.
 Dina ändringar har inte sparats.
 Could not get a lock to merge!
@@ -431,7 +430,7 @@ förfader
 other
 annan
 Run Maintenance
-
+Utför underhåll
 Maintenance not done.
 Underhåll ej slutfört.
 (Maintenance can only be done once every 12 hours.)
@@ -443,11 +442,11 @@ Huvudlås påslaget.
 Expiring keep files and deleting pages marked for deletion
 Avlägsnar "keep"-filer och raderar sidor märkta för radering
 not deleted: 
-
+ej borttagen:
 deleted
 borttagen
 Moving part of the %s log file.
-Flyttar del av %s-loggen
+Flyttar del av %s-loggen.
 Moving %s log entries.
 Flyttar %s loggnotering.
 Getting page index file for %s.
@@ -475,7 +474,7 @@ Visa beroenden
 Inter links:
 Interlänkar:
 Near links:
-Nära länkar:
+Närlänkar:
 Show parsed link data
 Visa tolkat länkdata
 Too many connections by %s
@@ -500,16 +499,18 @@ The page %s does not exist
 Sidan %s finnes inte
 The page %s already exists
 Sidan %s finns redan
+Cannot rename %1 to %2
+Kan inte byta namn på %1 till %2
 Renamed to %s
 Bytt namn till %s
 Renamed from %s
 Bytt namn från %s
 Renamed %1 to %2.
-Bytt namn på %1 till %2
+Bytt namn på %1 till %2.
 Immediately delete %s
-
+Radera %s direkt
 Rename %s to:
-
+Byt namn på %s till:
 Cannot highlight the language %s.
 Kan ej markera språket %s.
 Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
@@ -524,10 +525,14 @@ Next
 Nästa
 Calendar %s
 Kalender %s
+Clustermap
+
+Pages without a Cluster
+
 Comments on 
-
+Kommentarer till 
 Comment on 
-
+Kommentar till 
 Compilation for %s
 Sammanställning för %s
 Compilation tag is missing a regular expression.
@@ -562,8 +567,44 @@ Template without parameters
 Mall utan parametrar
 The template %s is either empty or does not exist.
 Mallen %s är antingen tom eller saknas.
-%s returned no data.
-%s returnerade inga data.
+Register for %s
+
+Please choose a username of the form "FirstLast" using your real name.
+
+The passwords do not match.
+
+The password must be at least %s characters.
+
+That email address is invalid.
+
+The username %s has already been registered.
+
+Your registration for %s has been submitted.
+
+  Please allow time for the webmaster to approve your request.
+
+An account was created for %s.
+
+Login to %s
+
+Username and/or password are incorrect.
+
+Logged in as %s.
+
+Logout of %s
+
+Logout of %s?
+
+Logged out of %s
+
+You are now logged out.
+
+Register a new account
+
+Login
+
+Logout
+
 Clearing Cache
 Rensar cachen
 Done.
@@ -572,10 +613,20 @@ Generating Link Database
 Skapar länkdatabas
 The 404 handler extension requires the link data extension (links.pl).
 404-hanterarmodulen kräver länkdatamodulen för att fungera (links.pl).
+LocalMap
+
+No page id for action localmap
+
+Requested page %s does not exist
+
+Local Map for %s
+
+view
+
 Orphan List
 Lista över övergivna sidor
 Trail: 
-
+Senast: 
 None
 Inga
 Type
@@ -585,33 +636,49 @@ Permanentlänk till "%s"
 Portrait
 Porträtt
 You did not answer correctly.
-Du svarade inte korrekt
+Du svarade inte korrekt.
 All Referrers
 Alla som länkat hit
 Referrers
 Sidor som länkat hit
-Updating %s
-Uppdaterar %s
+Rebuild index for searching
+
+Rebuilding Index
+
+Search::FreeText is not available on this system.
+
+Rebuilding index not done.
+
+(Rebuilding the index can only be done once every 12 hours.)
+
 Search term missing.
-Sökord saknas
+Sökord saknas.
+Result pages: 
+
+(%s results)
+
+Slideshow:%s
+
 Static Copy
 Statisk kopia
 Back to %s
 Tillbaka till %s
+Tag
+
 Alternatively, use one of the following templates:
 Eller använd en av följande mallar:
 Thread: %s
 Tråd: %s
 ID parameter is missing.
-ID-parametern saknas
+ID-parametern saknas.
 Thread %s does not exist.
-Tråden %s finns inte
+Tråden %s finns inte.
 Page %s does not contain a thread.
-Sidan %s innehåller ingen tråd
+Sidan %s innehåller ingen tråd.
 Add
 Lägg till
 URL parameter is missing.
-URL-parametern saknas
+URL-parametern saknas.
 Add to %s thread
 Lägg till till %s-tråden
 Below:
@@ -625,7 +692,7 @@ Misslyckades med att ta bort %s
 Contents
 Innehåll
 This page is a translation of %s. 
-
+Denna sida är en översättning av %s. 
 The translation is up to date.
 Denna översättning är aktuell.
 The translation is outdated.
@@ -633,13 +700,13 @@ Denna översättning är föråldrad
 The page does not exist.
 Sidan finns inte.
 http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
-
+http://www.adlibris.se/shop/product.asp?isbn=%s
 http://www.amazon.com/exec/obidos/ISBN=%s
 
 alternate
 alternativ
 http://www.pricescan.com/books/BookDetail.asp?isbn=%s
-
+http://www.bokpris.com/%s
 search
 sök
 Blog
